---
title: <span class="badge builder"></span> QueryEditorPropertyExpression
---
# <span class="badge builder"></span> QueryEditorPropertyExpression

## Constructor

```python
QueryEditorPropertyExpression()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> bigquery.QueryEditorPropertyExpression
```

### <span class="badge object-method"></span> property_val

```python
def property_val(property_val: cogbuilder.Builder[bigquery.QueryEditorProperty]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [QueryEditorPropertyExpression](./object-QueryEditorPropertyExpression.md)
